@@ -10,12 +10,12 @@ $(document).ready(function() {
         ws = new MozWebSocket(websocket);
     }
     else {
-        console.log("WebSocket Not Supported");
+        alert("WebSocket Not Supported");
         return;
     }
 
     window.onbeforeunload = function(e) {
-        $("#chat").val($("#chat").val() + "Bye bye...\n");
+        console.log("Bye bye...");
         ws.close(1000, "%(username)s left the room");
 
         if (!e) e = window.event;
@@ -27,43 +27,35 @@ $(document).ready(function() {
 
         // Execute a void command:
         if (evt.data.indexOf("$") === 0) {
-            var command = evt.data.substr(1)
+            var command = evt.data.substr(1);
             //console.log('exec of [ ' + command + ' ]');
             eval(command);
         }
 
         // Execute a command and return the synchronously:
-        else if (evt.data.indexOf("?") == 0) {
-            var command = evt.data.substr(1).split('=', 2)
-            console.log('raw command = [ ' + command + ' ]');
+        else if (evt.data.indexOf("?") === 0) {
+            var command = evt.data.substr(1).split("=", 2);
+            console.log("raw command = [ " + command + " ]");
             var callback_id = command[0];
             var command = command[1];
-            console.log('callback_id = [ ' + callback_id + ' ]');
-            console.log('processed command = [ ' + command + ' ]');
+            console.log("callback_id = [ " + callback_id + " ]");
+            console.log("processed command = [ " + command + " ]");
             try {
                 var result = eval(command);
-                console.log('result = [' + result + ']');
-                ws.send('?' + callback_id + '=' + typeof(result) + ':' + result);
+                console.log("result = [" + result + "]");
+                ws.send("?" + callback_id + "=" + typeof(result) + ":" + result);
             }
             catch(err) {
-                console.log('error : ' + err.name + err.message);
-                ws.send('!' + callback_id + '=' + err.name + ':' + err.message);
+                console.log("error : " + err.name + err.message);
+                ws.send("!" + callback_id + "=" + err.name + ":" + err.message);
             }
         }
-        $('#chat').val($('#chat').val() + evt.data + '\n');
+        console.log("log" + evt.data);
     };
     ws.onopen = function() {
         ws.send("%(username)s entered the room");
     };
     ws.onclose = function(evt) {
-        $('#chat').val($('#chat').val() + 'Connection closed by server: ' + evt.code + ' "' + evt.reason + '"\n');
+        $("#stderr").val("Connection closed by server: " + evt.code + " \"" + evt.reason + "\"\n");
     };
-
-    $('#send').click(function() {
-        console.log($('#message').val());
-        ws.send($('#message').val());
-        //ws.send('%(username)s: ' + $('#message').val());
-        $('#message').val("");
-        return false;
-    });
 });
\ No newline at end of file
